@@ -83,7 +83,7 @@ Widget::Widget(QWidget *parent) : QProgressBar (parent)
 	v2layout = new QVBoxLayout;
 	layout = new QHBoxLayout;
 	barColor = new QPushButton("BAR COLOR");
-	backColor = new QPushButton("BACKROUND COLOR");
+	backColor = new QPushButton("BACKGROUND COLOR");
 	textColor = new QPushButton("TEXT COLOR");
 	styleButton = new QMaemo5ValueButton("SELECT STYLE");
 	applyOnlyStyleButton = new QPushButton("APPLY ONLY STYLE");
@@ -98,6 +98,7 @@ Widget::Widget(QWidget *parent) : QProgressBar (parent)
 	_maemo5Style = new QMaemo5Style;
 
 	// detailed info window objects
+	_processPtr = new QProcess(this);
 	battInfo = new QTextBrowser;
 	//QMaemo5KineticScroller* ks = new QMaemo5KineticScroller(battInfo);
 	battInfo->setAttribute(Qt::WA_DeleteOnClose);
@@ -126,6 +127,10 @@ Widget::Widget(QWidget *parent) : QProgressBar (parent)
 		styleSelectionModel->appendRow(item);
 	}
 
+	// connect's for the detail window
+	connect(_processPtr, SIGNAL(finished(int , QProcess::ExitStatus)), this, SLOT(cmdFinished(int , QProcess::ExitStatus)) );
+
+	// connects for the style window
 	connect(barColor, SIGNAL(clicked()), barColorDialog, SLOT(show()));
 	connect(backColor, SIGNAL(clicked()), backColorDialog, SLOT(show()));
 	connect(textColor, SIGNAL(clicked()), textColorDialog, SLOT(show()));
@@ -181,27 +186,27 @@ bool Widget::x11Event ( XEvent * event )
 
 void Widget::mousePressEvent ( QMouseEvent * event )
 {
-		QString cmd("/home/user/run_lshal");
-		_processPtr = new QProcess(this);
-		connect(_processPtr, SIGNAL(finished(int , QProcess::ExitStatus)), this, SLOT(cmdFinished(int , QProcess::ExitStatus)) );
+	QString cmd("/home/user/run_lshal");
 
-		_processPtr->start(cmd);
-		_processPtr->waitForFinished();
+	_processPtr->start(cmd);
+	_processPtr->waitForFinished();
 }
 
 void Widget::cmdFinished( int exitCode, QProcess::ExitStatus exitStatus )
 {
-		while (!_processPtr->atEnd())
-		{
-			QByteArray byteArray = _processPtr->readLine();
-			QString line(byteArray);
-			battInfo->append(line);
-		}
-		battInfo->setReadOnly(true);
-		battInfo->moveCursor(QTextCursor::Start);
+	battInfo->clear();
 
-		detailWindow->setCentralWidget(battInfo);
-		detailWindow->show();
+	while (!_processPtr->atEnd())
+	{
+		QByteArray byteArray = _processPtr->readLine();
+		QString line(byteArray);
+		battInfo->append(line);
+	}
+	battInfo->setReadOnly(true);
+	battInfo->moveCursor(QTextCursor::Start);
+
+	detailWindow->setCentralWidget(battInfo);
+	detailWindow->show();
 }
 
 void Widget::changeBarColor(QColor color)
